@@ -4,8 +4,8 @@ from sqlalchemy import (
     Column,
     Integer,
     DateTime,
-    ForeignKey,
     String,
+    Float,
     Boolean,
 )
 
@@ -27,6 +27,8 @@ class InterventionDataRawModel(Base):
     insight_name = Column(
         String(191),
     )
+    score = Column(Float, nullable=True)
+    preferred = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
