@@ -5,8 +5,8 @@ from sqlalchemy import (
     Integer,
     DateTime,
     ForeignKey,
-    String,
     Float,
+    Boolean,
 )
 
 from ...database import Base
@@ -26,7 +26,8 @@ class InterventionNCTModel(Base):
         ForeignKey('nct_study.id'),
         nullable=False,
     )
-    match_score = Column(Float, nullable=False)
+    score = Column(Float, nullable=False)
+    preferred = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
