@@ -11,5 +11,6 @@ class InterventionNCTResourceSchema(Schema):
     id = fields.Integer(dump_only=True)
     intervention_id = fields.Integer(required=True)
     nct_study_id = fields.Integer(required=True)
-    match_score = fields.Float(required=True)
+    score = fields.Float(required=True)
+    preferred = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
