@@ -7,6 +7,7 @@ from sqlalchemy import (
     DateTime,
     UniqueConstraint,
     ForeignKey,
+    Boolean,
 )
 
 from ...database import Base
@@ -16,7 +17,6 @@ class InterventionRelsModel(Base):
     __tablename__ = "intervention_rels"
 
     id = Column(Integer, primary_key=True)
-    nct_id = Column(String(128), nullable=False, index=True)
     intervention_id_1 = Column(
         Integer,
         ForeignKey('interventions.id'),
@@ -27,6 +27,8 @@ class InterventionRelsModel(Base):
         ForeignKey('interventions.id'),
         nullable=False,
     )
+    relation = Column(String(128), nullable=False, index=True)
+    is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
@@ -35,4 +37,4 @@ class InterventionRelsModel(Base):
         onupdate=lambda: datetime.utcnow(),
     )
 
-    __table_args__ = (UniqueConstraint("nct_id", "intervention_id_1", "intervention_id_2"),)
+    __table_args__ = (UniqueConstraint("intervention_id_1", "intervention_id_2", "relation"),)
