@@ -23,7 +23,7 @@ class MergerOutboxResourceSchema(Schema):
     updated_at = fields.DateTime()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['announcement_date']
 
         in_data = pre_load_date_fields(
