@@ -16,7 +16,7 @@ class PubmedTargetModel(Base):
     __tablename__ = "pubmed_targets"
 
     id = Column(Integer, primary_key=True)
-    pubmed = Column(
+    pubmed_id = Column(
         Integer,
         ForeignKey('pubmed.id'),
         nullable=False,
@@ -31,6 +31,7 @@ class PubmedTargetModel(Base):
         nullable=False,
     )
     preferred = Column(Boolean, nullable=True)
+    data_readout = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
