@@ -13,4 +13,6 @@ class SRCIdConditionResourceSchema(Schema):
     src_type = fields.String(validate=not_blank, required=True)
     condition_id = fields.Integer(required=True)
     is_deleted = fields.Boolean(allow_none=True)
+    score = fields.Integer(allow_none=True)
+    final_mapping = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
